@@ -1,5 +1,5 @@
 /*
- * SPDX-FileCopyrightText: 2019-2020 Laurent Montel <montel@kde.org>
+ * SPDX-FileCopyrightText: 2019-2021 Laurent Montel <montel@kde.org>
  *
  * SPDX-License-Identifier: LGPL-2.0-or-later
  */
@@ -9,62 +9,27 @@
 #include <QLabel>
 #include <QListWidget>
 #include <QListWidgetItem>
+#include <QPushButton>
 #include <QToolButton>
 #include <QVBoxLayout>
-#include <QPushButton>
 
 #include <KConfig>
 #include <KConfigGroup>
-#include <QDialogButtonBox>
-#include <QHBoxLayout>
 #include <KLocalizedString>
 #include <KMessageBox>
+#include <QDialogButtonBox>
+#include <QHBoxLayout>
 
 #include "ldapclientsearch.h"
 #include "ldapclientsearchconfig.h"
+#include "ldapclientsearchconfigwriteconfigjob.h"
+#include "ldapwidgetitem_p.h"
+#include "ldapwidgetitemreadconfigserverjob.h"
 #include <kldap/ldapserver.h>
 
 #include "addhostdialog.h"
 
 using namespace KLDAP;
-class LDAPItem : public QListWidgetItem
-{
-public:
-    LDAPItem(QListWidget *parent, const KLDAP::LdapServer &server, bool isActive = false)
-        : QListWidgetItem(parent, QListWidgetItem::UserType)
-        , mIsActive(isActive)
-    {
-        setFlags(Qt::ItemIsEnabled | Qt::ItemIsSelectable | Qt::ItemIsUserCheckable);
-        setCheckState(isActive ? Qt::Checked : Qt::Unchecked);
-        setServer(server);
-    }
-
-    void setServer(const KLDAP::LdapServer &server)
-    {
-        mServer = server;
-
-        setText(mServer.host());
-    }
-
-    const KLDAP::LdapServer &server() const
-    {
-        return mServer;
-    }
-
-    void setIsActive(bool isActive)
-    {
-        mIsActive = isActive;
-    }
-
-    bool isActive() const
-    {
-        return mIsActive;
-    }
-
-private:
-    KLDAP::LdapServer mServer;
-    bool mIsActive = false;
-};
 
 LdapConfigureWidget::LdapConfigureWidget(QWidget *parent)
     : QWidget(parent)
@@ -96,7 +61,7 @@ void LdapConfigureWidget::slotSelectionChanged(QListWidgetItem *item)
 
 void LdapConfigureWidget::slotItemClicked(QListWidgetItem *item)
 {
-    auto *ldapItem = dynamic_cast<LDAPItem *>(item);
+    auto *ldapItem = dynamic_cast<LdapWidgetItem *>(item);
     if (!ldapItem) {
         return;
     }
@@ -112,8 +77,9 @@ void LdapConfigureWidget::slotAddHost()
     KLDAP::LdapServer server;
     KLDAP::AddHostDialog dlg(&server, this);
 
-    if (dlg.exec() && !server.host().trimmed().isEmpty()) {   //krazy:exclude=crashy
-        new LDAPItem(mHostListView, server);
+    if (dlg.exec() && !server.host().trimmed().isEmpty()) { // krazy:exclude=crashy
+        auto item = new LdapWidgetItem(mHostListView);
+        item->setServer(server);
 
         Q_EMIT changed(true);
     }
@@ -121,7 +87,7 @@ void LdapConfigureWidget::slotAddHost()
 
 void LdapConfigureWidget::slotEditHost()
 {
-    auto *item = dynamic_cast<LDAPItem *>(mHostListView->currentItem());
+    auto *item = dynamic_cast<LdapWidgetItem *>(mHostListView->currentItem());
     if (!item) {
         return;
     }
@@ -130,7 +96,7 @@ void LdapConfigureWidget::slotEditHost()
     KLDAP::AddHostDialog dlg(&server, this);
     dlg.setWindowTitle(i18nc("@title:window", "Edit Host"));
 
-    if (dlg.exec() && !server.host().isEmpty()) {   //krazy:exclude=crashy
+    if (dlg.exec() && !server.host().isEmpty()) { // krazy:exclude=crashy
         item->setServer(server);
 
         Q_EMIT changed(true);
@@ -143,8 +109,9 @@ void LdapConfigureWidget::slotRemoveHost()
     if (!item) {
         return;
     }
-    auto *ldapItem = dynamic_cast<LDAPItem *>(item);
-    if (KMessageBox::No == KMessageBox::questionYesNo(this, i18n("Do you want to remove setting for host \"%1\"?", ldapItem->server().host()), i18n("Remove Host"))) {
+    auto *ldapItem = dynamic_cast<LdapWidgetItem *>(item);
+    if (KMessageBox::No
+        == KMessageBox::questionYesNo(this, i18n("Do you want to remove setting for host \"%1\"?", ldapItem->server().host()), i18n("Remove Host"))) {
         return;
     }
 
@@ -155,7 +122,7 @@ void LdapConfigureWidget::slotRemoveHost()
     Q_EMIT changed(true);
 }
 
-static void swapItems(LDAPItem *item, LDAPItem *other)
+static void swapItems(LdapWidgetItem *item, LdapWidgetItem *other)
 {
     KLDAP::LdapServer server = item->server();
     bool isActive = item->isActive();
@@ -174,12 +141,12 @@ void LdapConfigureWidget::slotMoveUp()
         return;
     }
 
-    LDAPItem *item = static_cast<LDAPItem *>(mHostListView->selectedItems().first());
+    LdapWidgetItem *item = static_cast<LdapWidgetItem *>(mHostListView->selectedItems().first());
     if (!item) {
         return;
     }
 
-    auto *above = static_cast<LDAPItem *>(mHostListView->item(mHostListView->row(item) - 1));
+    auto above = static_cast<LdapWidgetItem *>(mHostListView->item(mHostListView->row(item) - 1));
     if (!above) {
         return;
     }
@@ -199,12 +166,12 @@ void LdapConfigureWidget::slotMoveDown()
         return;
     }
 
-    LDAPItem *item = static_cast<LDAPItem *>(mHostListView->selectedItems().first());
+    LdapWidgetItem *item = static_cast<LdapWidgetItem *>(mHostListView->selectedItems().first());
     if (!item) {
         return;
     }
 
-    auto *below = static_cast<LDAPItem *>(mHostListView->item(mHostListView->row(item) + 1));
+    auto below = static_cast<LdapWidgetItem *>(mHostListView->item(mHostListView->row(item) + 1));
     if (!below) {
         return;
     }
@@ -225,17 +192,25 @@ void LdapConfigureWidget::load()
 
     int count = group.readEntry("NumSelectedHosts", 0);
     for (int i = 0; i < count; ++i) {
-        KLDAP::LdapServer server;
-        mClientSearchConfig->readConfig(server, group, i, true);
-        auto *item = new LDAPItem(mHostListView, server, true);
+        auto item = new LdapWidgetItem(mHostListView, true);
         item->setCheckState(Qt::Checked);
+        auto job = new LdapWidgetItemReadConfigServerJob(this);
+        job->setCurrentIndex(i);
+        job->setActive(true);
+        job->setConfig(group);
+        job->setLdapWidgetItem(item);
+        job->start();
     }
 
     count = group.readEntry("NumHosts", 0);
     for (int i = 0; i < count; ++i) {
-        KLDAP::LdapServer server;
-        mClientSearchConfig->readConfig(server, group, i, false);
-        new LDAPItem(mHostListView, server);
+        auto item = new LdapWidgetItem(mHostListView);
+        auto job = new LdapWidgetItemReadConfigServerJob(this);
+        job->setCurrentIndex(i);
+        job->setActive(false);
+        job->setConfig(group);
+        job->setLdapWidgetItem(item);
+        job->start();
     }
 
     Q_EMIT changed(false);
@@ -243,7 +218,7 @@ void LdapConfigureWidget::load()
 
 void LdapConfigureWidget::save()
 {
-    mClientSearchConfig->clearWalletPassword();
+    // mClientSearchConfig->clearWalletPassword();
     KConfig *config = KLDAP::LdapClientSearchConfig::config();
     config->deleteGroup("LDAP");
 
@@ -252,17 +227,27 @@ void LdapConfigureWidget::save()
     int selected = 0;
     int unselected = 0;
     for (int i = 0; i < mHostListView->count(); ++i) {
-        auto *item = dynamic_cast<LDAPItem *>(mHostListView->item(i));
+        auto *item = dynamic_cast<LdapWidgetItem *>(mHostListView->item(i));
         if (!item) {
             continue;
         }
 
         KLDAP::LdapServer server = item->server();
         if (item->checkState() == Qt::Checked) {
-            mClientSearchConfig->writeConfig(server, group, selected, true);
+            auto job = new LdapClientSearchConfigWriteConfigJob;
+            job->setActive(true);
+            job->setConfig(group);
+            job->setServerIndex(selected);
+            job->setServer(server);
+            job->start();
             selected++;
         } else {
-            mClientSearchConfig->writeConfig(server, group, unselected, false);
+            auto job = new LdapClientSearchConfigWriteConfigJob;
+            job->setActive(false);
+            job->setConfig(group);
+            job->setServerIndex(unselected);
+            job->setServer(server);
+            job->start();
             unselected++;
         }
     }
@@ -276,13 +261,13 @@ void LdapConfigureWidget::save()
 
 void LdapConfigureWidget::initGUI()
 {
-    auto *layout = new QVBoxLayout(this);
+    auto layout = new QVBoxLayout(this);
     layout->setObjectName(QStringLiteral("layout"));
     layout->setContentsMargins(0, 0, 0, 0);
 
     QGroupBox *groupBox = new QGroupBox(i18n("LDAP Servers"));
     layout->addWidget(groupBox);
-    auto *mainLayout = new QVBoxLayout;
+    auto mainLayout = new QVBoxLayout;
     mainLayout->setObjectName(QStringLiteral("mainlayout"));
     groupBox->setLayout(mainLayout);
 
@@ -293,7 +278,7 @@ void LdapConfigureWidget::initGUI()
     QWidget *hBox = new QWidget(this);
     mainLayout->addWidget(hBox);
 
-    auto *hBoxHBoxLayout = new QHBoxLayout(hBox);
+    auto hBoxHBoxLayout = new QHBoxLayout(hBox);
     hBoxHBoxLayout->setContentsMargins(0, 0, 0, 0);
     hBoxHBoxLayout->setSpacing(6);
     // Contents of the hbox: listview and up/down buttons on the right (vbox)
@@ -302,34 +287,31 @@ void LdapConfigureWidget::initGUI()
     mHostListView->setSortingEnabled(false);
 
     QWidget *upDownBox = new QWidget(hBox);
-    auto *upDownBoxVBoxLayout = new QVBoxLayout(upDownBox);
+    auto upDownBoxVBoxLayout = new QVBoxLayout(upDownBox);
     upDownBoxVBoxLayout->setContentsMargins(0, 0, 0, 0);
     hBoxHBoxLayout->addWidget(upDownBox);
     upDownBoxVBoxLayout->setSpacing(6);
     mUpButton = new QToolButton(upDownBox);
     upDownBoxVBoxLayout->addWidget(mUpButton);
     mUpButton->setIcon(QIcon::fromTheme(QStringLiteral("go-up")));
-    mUpButton->setEnabled(false);   // b/c no item is selected yet
+    mUpButton->setEnabled(false); // b/c no item is selected yet
 
     mDownButton = new QToolButton(upDownBox);
     upDownBoxVBoxLayout->addWidget(mDownButton);
     mDownButton->setIcon(QIcon::fromTheme(QStringLiteral("go-down")));
-    mDownButton->setEnabled(false);   // b/c no item is selected yet
+    mDownButton->setEnabled(false); // b/c no item is selected yet
 
     QWidget *spacer = new QWidget(upDownBox);
     upDownBoxVBoxLayout->addWidget(spacer);
     upDownBoxVBoxLayout->setStretchFactor(spacer, 100);
 
-    auto *buttons = new QDialogButtonBox(this);
-    QPushButton *add = buttons->addButton(i18n("&Add Host..."),
-                                          QDialogButtonBox::ActionRole);
+    auto buttons = new QDialogButtonBox(this);
+    QPushButton *add = buttons->addButton(i18n("&Add Host..."), QDialogButtonBox::ActionRole);
     connect(add, &QPushButton::clicked, this, &LdapConfigureWidget::slotAddHost);
-    mEditButton = buttons->addButton(i18n("&Edit Host..."),
-                                     QDialogButtonBox::ActionRole);
+    mEditButton = buttons->addButton(i18n("&Edit Host..."), QDialogButtonBox::ActionRole);
     connect(mEditButton, &QPushButton::clicked, this, &LdapConfigureWidget::slotEditHost);
     mEditButton->setEnabled(false);
-    mRemoveButton = buttons->addButton(i18n("&Remove Host"),
-                                       QDialogButtonBox::ActionRole);
+    mRemoveButton = buttons->addButton(i18n("&Remove Host"), QDialogButtonBox::ActionRole);
     connect(mRemoveButton, &QPushButton::clicked, this, &LdapConfigureWidget::slotRemoveHost);
     mRemoveButton->setEnabled(false);
     buttons->layout();
